package fuku.webbook;

/**
 * HTMLユーティリティクラス。
 *
 * @author Hisaya FUKUMOTO
 * @version 0.3.5
 */
public final class HTMLUtil {

    /**
     * コンストラクタ。
     *
     */
    private HTMLUtil() {
        super();
    }


    /**
     * 指定された文字列内の特殊文字を文字参照に変換します。
     *
     * @param str 文字列
     * @return 変換後の文字列
     */
    public static String encode(String str) {
        if (str == null || str.length() <= 0) {
            return str;
        }
        StringBuffer buff = new StringBuffer(str);
        int len = buff.length();
        for (int i=0; i<len; i++) {
            switch (buff.charAt(i)) {
                case '&':
                    boolean ref = false;
                    for (int j=i+1; j<len; j++) {
                        char ch = buff.charAt(j);
                        if (ch == ';') {
                            ref = true;
                            break;
                        }
                        if (!CharType.isAlphaNum(ch)) {
                            break;
                        }
                    }
                    if (!ref) {
                        buff.replace(i, i+1, "&amp;");
                        i += 4;
                        len += 4;
                    }
                    break;
                case '<':
                    buff.replace(i, i+1, "&lt;");
                    i += 3;
                    len += 3;
                    break;
                case '>':
                    buff.replace(i, i+1, "&gt;");
                    i += 3;
                    len += 3;
                    break;
                case '"':
                    buff.replace(i, i+1, "&quot;");
                    i += 5;
                    len += 5;
                    break;
//                  case ' ':
//                      buff.replace(i, i+1, "&nbsp;");
//                      i += 5;
//                      len += 5;
//                      break;
                default:
                    break;
            }
        }
        return buff.toString();
    }

    /**
     * 指定された文字列内の文字参照を特殊文字に変換します。
     *
     * @param str 文字列
     * @return 変換後の文字列
     */
    public static String decode(String str) {
        if (str == null || str.length() <= 0) {
            return str;
        }
        StringBuffer buff = new StringBuffer(str);
        int len = buff.length();
        for (int i=0; i<len; i++) {
            if (buff.charAt(i) == '&') {
                if (buff.indexOf("&amp;", i) == i) {
                    buff.delete(i+1, i+5);
                    len -= 4;
                } else if (buff.indexOf("&lt;", i) == i) {
                    buff.replace(i, i+4, "<");
                    len -= 3;
                } else if (buff.indexOf("&gt;", i) == i) {
                    buff.replace(i, i+4, ">");
                    len -= 3;
                } else if (buff.indexOf("&quot;", i) == i) {
                    buff.replace(i, i+6, "\"");
                    len -= 5;
                } else if (buff.indexOf("&nbsp;", i) == i) {
                    buff.replace(i, i+6, " ");
                    len -= 5;
                }
            }
        }
        return buff.toString();
    }
}

// end of HTMLUtil.java
